==> webkit2gtk_2.16.6.orig.tar.xz: webkitgtk-2.16.6/Source/JavaScriptCore/runtime/ArrayBufferNeuteringWatchpoint.cpp <==
/*
 * Copyright (C) 2013 Apple Inc. All rights reserved.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions
 * are met:
 * 1. Redistributions of source code must retain the above copyright
 *    notice, this list of conditions and the following disclaimer.
 * 2. Redistributions in binary form must reproduce the above copyright
 *    notice, this list of conditions and the following disclaimer in the
 *    documentation and/or other materials provided with the distribution.
 *
 * THIS SOFTWARE IS PROVIDED BY APPLE INC. ``AS IS'' AND ANY
 * EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
 * IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR
 * PURPOSE ARE DISCLAIMED.  IN NO EVENT SHALL APPLE INC. OR
 * CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL,
 * EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO,
 * PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR
 * PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY
 * OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT
 * (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE
 * OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE. 
 */

#include "config.h"
#include "ArrayBufferNeuteringWatchpoint.h"

#include "JSCInlines.h"

namespace JSC {

const ClassInfo ArrayBufferNeuteringWatchpoint::s_info = {
    "ArrayBufferNeuteringWatchpoint", 0, 0,
    CREATE_METHOD_TABLE(ArrayBufferNeuteringWatchpoint)
};

ArrayBufferNeuteringWatchpoint::ArrayBufferNeuteringWatchpoint(VM& vm)
    : Base(vm, vm.arrayBufferNeuteringWatchpointStructure.get())
    , m_set(adoptRef(new WatchpointSet(IsWatched)))
{
}

void ArrayBufferNeuteringWatchpoint::destroy(JSCell* cell)
{
    static_cast<ArrayBufferNeuteringWatchpoint*>(cell)->ArrayBufferNeuteringWatchpoint::~ArrayBufferNeuteringWatchpoint();
}

ArrayBufferNeuteringWatchpoint* ArrayBufferNeuteringWatchpoint::create(VM& vm)
{
    ArrayBufferNeuteringWatchpoint* result = new
        (NotNull, allocateCell<ArrayBufferNeuteringWatchpoint>(vm.heap))
        ArrayBufferNeuteringWatchpoint(vm);
    result->finishCreation(vm);
    return result;
}

Structure* ArrayBufferNeuteringWatchpoint::createStructure(VM& vm)
{
    return Structure::create(vm, 0, jsNull(), TypeInfo(CellType, StructureFlags), info());
}

void ArrayBufferNeuteringWatchpoint::fireAll()
{
    set()->fireAll(*vm(), "Array buffer was neutered");
}

} // namespace JSC

==> webkit2gtk_2.20.5.orig.tar.xz: webkitgtk-2.20.5/Source/JavaScriptCore/runtime/ArrayBufferNeuteringWatchpoint.cpp <==
/*
 * Copyright (C) 2013 Apple Inc. All rights reserved.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions
 * are met:
 * 1. Redistributions of source code must retain the above copyright
 *    notice, this list of conditions and the following disclaimer.
 * 2. Redistributions in binary form must reproduce the above copyright
 *    notice, this list of conditions and the following disclaimer in the
 *    documentation and/or other materials provided with the distribution.
 *
 * THIS SOFTWARE IS PROVIDED BY APPLE INC. ``AS IS'' AND ANY
 * EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
 * IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR
 * PURPOSE ARE DISCLAIMED.  IN NO EVENT SHALL APPLE INC. OR
 * CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL,
 * EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO,
 * PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR
 * PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY
 * OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT
 * (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE
 * OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE. 
 */

#include "config.h"
#include "ArrayBufferNeuteringWatchpoint.h"

#include "JSCInlines.h"

namespace JSC {

const ClassInfo ArrayBufferNeuteringWatchpoint::s_info = {
    "ArrayBufferNeuteringWatchpoint", nullptr, nullptr, nullptr,
    CREATE_METHOD_TABLE(ArrayBufferNeuteringWatchpoint)
};

ArrayBufferNeuteringWatchpoint::ArrayBufferNeuteringWatchpoint(VM& vm)
    : Base(vm, vm.arrayBufferNeuteringWatchpointStructure.get())
    , m_set(adoptRef(new WatchpointSet(IsWatched)))
{
}

void ArrayBufferNeuteringWatchpoint::destroy(JSCell* cell)
{
    static_cast<ArrayBufferNeuteringWatchpoint*>(cell)->ArrayBufferNeuteringWatchpoint::~ArrayBufferNeuteringWatchpoint();
}

ArrayBufferNeuteringWatchpoint* ArrayBufferNeuteringWatchpoint::create(VM& vm)
{
    ArrayBufferNeuteringWatchpoint* result = new
        (NotNull, allocateCell<ArrayBufferNeuteringWatchpoint>(vm.heap))
        ArrayBufferNeuteringWatchpoint(vm);
    result->finishCreation(vm);
    return result;
}

Structure* ArrayBufferNeuteringWatchpoint::createStructure(VM& vm)
{
    return Structure::create(vm, 0, jsNull(), TypeInfo(CellType, StructureFlags), info());
}

void ArrayBufferNeuteringWatchpoint::fireAll()
{
    set()->fireAll(*vm(), "Array buffer was neutered");
}

} // namespace JSC
